==> aws-cdk.aws-stepfunctions-tasks-1.60.0.tar.gz: aws-cdk.aws-stepfunctions-tasks-1.60.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-stepfunctions-tasks",
    "version": "1.60.0",
    "description": "Task integrations for AWS StepFunctions",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_stepfunctions_tasks",
        "aws_cdk.aws_stepfunctions_tasks._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_stepfunctions_tasks._jsii": [
            "aws-stepfunctions-tasks@1.60.0.jsii.tgz"
        ],
        "aws_cdk.aws_stepfunctions_tasks": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii>=1.9.0, <2.0.0",
        "publication>=0.0.3",
        "aws-cdk.assets==1.60.0",
        "aws-cdk.aws-batch==1.60.0",
        "aws-cdk.aws-cloudwatch==1.60.0",
        "aws-cdk.aws-dynamodb==1.60.0",
        "aws-cdk.aws-ec2==1.60.0",
        "aws-cdk.aws-ecr==1.60.0",
        "aws-cdk.aws-ecr-assets==1.60.0",
        "aws-cdk.aws-ecs==1.60.0",
        "aws-cdk.aws-glue==1.60.0",
        "aws-cdk.aws-iam==1.60.0",
        "aws-cdk.aws-kms==1.60.0",
        "aws-cdk.aws-lambda==1.60.0",
        "aws-cdk.aws-s3==1.60.0",
        "aws-cdk.aws-sns==1.60.0",
        "aws-cdk.aws-sqs==1.60.0",
        "aws-cdk.aws-stepfunctions==1.60.0",
        "aws-cdk.core==1.60.0",
        "constructs>=3.0.2, <4.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ]
}
"""
)

with open("README.md") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-stepfunctions-tasks-1.62.0.tar.gz: aws-cdk.aws-stepfunctions-tasks-1.62.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-stepfunctions-tasks",
    "version": "1.62.0",
    "description": "Task integrations for AWS StepFunctions",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_stepfunctions_tasks",
        "aws_cdk.aws_stepfunctions_tasks._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_stepfunctions_tasks._jsii": [
            "aws-stepfunctions-tasks@1.62.0.jsii.tgz"
        ],
        "aws_cdk.aws_stepfunctions_tasks": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.assets==1.62.0",
        "aws-cdk.aws-batch==1.62.0",
        "aws-cdk.aws-cloudwatch==1.62.0",
        "aws-cdk.aws-codebuild==1.62.0",
        "aws-cdk.aws-dynamodb==1.62.0",
        "aws-cdk.aws-ec2==1.62.0",
        "aws-cdk.aws-ecr-assets==1.62.0",
        "aws-cdk.aws-ecr==1.62.0",
        "aws-cdk.aws-ecs==1.62.0",
        "aws-cdk.aws-glue==1.62.0",
        "aws-cdk.aws-iam==1.62.0",
        "aws-cdk.aws-kms==1.62.0",
        "aws-cdk.aws-lambda==1.62.0",
        "aws-cdk.aws-s3==1.62.0",
        "aws-cdk.aws-sns==1.62.0",
        "aws-cdk.aws-sqs==1.62.0",
        "aws-cdk.aws-stepfunctions==1.62.0",
        "aws-cdk.core==1.62.0",
        "constructs>=3.0.4, <4.0.0",
        "jsii>=1.11.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ]
}
"""
)

with open("README.md") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
